@@ -59,7 +59,6 @@ var runStatistics bool
 var ignoreHCLErrors bool
 var stopOnCheckError bool
 var workspace string
-var passingGif bool
 var sortSeverity bool
 
 func init() {
@@ -68,7 +67,7 @@ func init() {
 	rootCmd.Flags().BoolVar(&disableColours, "no-color", disableColours, "Disable colored output (American style!)")
 	rootCmd.Flags().BoolVarP(&showVersion, "version", "v", showVersion, "Show version information and exit")
 	rootCmd.Flags().BoolVar(&runUpdate, "update", runUpdate, "Update to latest version")
-	rootCmd.Flags().StringVarP(&format, "format", "f", format, "Select output format(s) comma separated: default, json, csv, checkstyle, junit, sarif")
+	rootCmd.Flags().StringVarP(&format, "format", "f", format, "Select output format(s) comma separated: default, json, csv, checkstyle, junit, sarif, gif")
 	rootCmd.Flags().StringVarP(&excludedRuleIDs, "exclude", "e", excludedRuleIDs, "Provide comma-separated list of rule IDs to exclude from run.")
 	rootCmd.Flags().StringVarP(&includedRuleIDs, "include", "i", includedRuleIDs, "Provide comma-separated list of specific rules to include in the from run.")
 	rootCmd.Flags().StringVar(&filterResults, "filter-results", filterResults, "Filter results to return specific checks only (supports comma-delimited input).")
@@ -89,7 +88,6 @@ func init() {
 	rootCmd.Flags().BoolVar(&ignoreInfo, "ignore-info", ignoreWarnings, "[DEPRECATED] Don't show info results in the output.")
 	rootCmd.Flags().BoolVarP(&stopOnCheckError, "allow-checks-to-panic", "p", stopOnCheckError, "Allow panics to propagate up from rule checking")
 	rootCmd.Flags().StringVarP(&workspace, "workspace", "w", workspace, "Specify a workspace for ignore limits")
-	rootCmd.Flags().BoolVar(&passingGif, "gif", passingGif, "Show a celebratory gif in the terminal if no problems are found (default formatter only)")
 	rootCmd.Flags().BoolVar(&sortSeverity, "sort-severity", sortSeverity, "Sort the results by severity from Critical to Low")
 
 }
@@ -432,9 +430,6 @@ func getFormatterOptions() []formatters.FormatterOption {
 	if includePassed {
 		options = append(options, formatters.IncludePassed)
 	}
-	if passingGif {
-		options = append(options, formatters.PassingGif)
-	}
 	return options
 }
 
@@ -533,6 +528,8 @@ func getFormatter(fileFormat string) (formatters.Formatter, error) {
 		return formatters.FormatText, nil
 	case "sarif":
 		return formatters.FormatSarif, nil
+	case "gif":
+		return formatters.FormatGif, nil
 	default:
 		return nil, fmt.Errorf("invalid format specified: '%s'", fileFormat)
 	}
