@@ -9,8 +9,6 @@ import (
 
 	"github.com/aquasecurity/tfsec/pkg/provider"
 
-	"github.com/aquasecurity/tfsec/internal/app/tfsec/hclcontext"
-
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
 
 	"github.com/aquasecurity/tfsec/pkg/rule"
@@ -60,7 +58,7 @@ resource "google_project_iam_member" "project" {
 		RequiredTypes:   []string{"resource"},
 		RequiredLabels:  []string{"google_project_iam_member"},
 		DefaultSeverity: severity.High,
-		CheckFunc: func(set result.Set, resourceBlock block.Block, ctx *hclcontext.Context) {
+		CheckFunc: func(set result.Set, resourceBlock block.Block, module block.Module) {
 
 			// is this a sensitive role?
 			roleAttr := resourceBlock.GetAttribute("role")
@@ -85,7 +83,7 @@ resource "google_project_iam_member" "project" {
 			}
 
 			// the service account may be populated via a templated reference that we don't have, so we need to check references
-			if serviceAccountBlock, err := ctx.GetReferencedBlock(memberAttr); err != nil {
+			if serviceAccountBlock, err := module.GetReferencedBlock(memberAttr); err != nil {
 				return
 			} else if serviceAccountBlock.IsNotNil() && serviceAccountBlock.TypeLabel() == "google_service_account" {
 				set.AddResult().
